#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_PROPERTIES_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_PROPERTIES_HPP_INCLUDED

#include <boost/simd/constant/include/constants/properties.hpp>

#endif
